<?php

namespace Teknisa\DF\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;

class ManifestacaoDestinatario extends \Teknisa\DF\Controllers\TeknisaCrud
{
    const DATASOURCE_NOTAFISCAL_FORN = 'manifestacao_destinatario_fornecedor';
    const DATASOURCE_NOTAFISCAL_CLIE = 'manifestacao_destinatario_cliente';
    const DATASOURCE_NOTAFISCAL_FILI = 'manifestacao_destinatario_filial';

    protected $dataSourceName = 'manifestacao_destinatario';
    protected $parameterBagColumns = array(
        'P_CDTIPOOPER',
        'P_IDSTATUSNFE',
        'P_DTEMISSAOINI',
        'P_DTEMISSAOFIN',
        'P_SINCRONIZACAO',
        'P_NRINSJURIEST',
        'P_NRACESSONFE',
        'P_IDENTRSAIDNF',
        'P_CDINSCESTA',
        'P_CDEMPRESA',
        'P_IDSTATUSNFENF',
        'P_IDENTRSAIDOP',
        'P_IDSTATUSMANIF',
        'P_IDORIGDESTNF',
        'P_NRINSJUREMIT'
    );

    public function find(DTO\Request\Filter $request, DTO\Response $response) {

        $filterCriteria = $request->getFilterCriteria();
        $conditions = $filterCriteria->getConditions();
        $keyRemoveIdorigdestnf = null;

        foreach ($conditions as $key => $condition) {
            if ($condition['columnName'] === 'P_IDORIGDESTNF') {
                $idorigdestnf = str_split($condition['value']);
                switch ($idorigdestnf) {
                    case in_array('F', $idorigdestnf):
                        $this->dataSourceName = self::DATASOURCE_NOTAFISCAL_FORN;
                        break;
                    case in_array('C', $idorigdestnf):
                        $this->dataSourceName = self::DATASOURCE_NOTAFISCAL_CLIE;
                        break;
                    case in_array('L', $idorigdestnf):
                        $this->dataSourceName = self::DATASOURCE_NOTAFISCAL_FILI;
                        break;
                }
                $keyRemoveIdorigdestnf = $key;
            }
        }

        if (is_numeric($keyRemoveIdorigdestnf))
            array_splice($conditions, $keyRemoveIdorigdestnf, 1);
        
        parent::find($request, $response);
        $dataSets = $response->getDataSets();
        $rows = isset($dataSets[0])? $dataSets[0]->getRows() : $dataSets;
        foreach ($rows as &$row) {
            $sincronizacao = 0;
            if(is_null($row['NRLANCTONFDEST'])  && !is_null($row['NRLANCTONF']) && $row['NRACESSONFE']) $sincronizacao = 0;
            else if(is_null($row['NRLANCTONFDEST']) && is_null($row['NRACESSOINTG'])) $sincronizacao = 1;
            else if($row['NRLANCTONFDEST']) $sincronizacao = 2;
            else if(is_null($row['NRLANCTONFDEST']) && $row['NRACESSOINTG']) $sincronizacao = 3;
            $row['SINCRONIZACAO'] = $sincronizacao;
        }
        $dataSet = new DataSet('manifestacao_destinatario', $rows);
        $response->setDataSets(array($dataSet));
    }
}